@@ -32,7 +32,7 @@ use Encode ();
 use MIME::Base64;
 use Scalar::Util ();
 
-our $VERSION = 1.4_03;
+our $VERSION = 1.4_04;
 
 my $apiVersion = undef;  # 0 for compatibility.  1 for prefered
 my $error;
@@ -935,8 +935,8 @@ sub _convert_rdn {
 	    my $oid = $item->{type};
 	    my $name = (exists $variantNames{$oid})? $variantNames{$oid}[1]: $oids{ $oid };
 	    if( defined $name ) {
-		push @{$hash{$name}}, values %{$item->{value}};
-		push @{$hash{_subject}}, $name, [ values %{$item->{value}} ];
+		push @{$hash{$name}}, sort values %{$item->{value}};
+		push @{$hash{_subject}}, $name, [ sort values %{$item->{value}} ];
 		my @names = (exists $variantNames{$oid})? @{$variantNames{$oid}} : ( $name );
 		foreach my $name ( @names ) {
 		    unless( $self->can( $name ) ) {
@@ -1030,7 +1030,7 @@ sub subjectAltName {
 	if( wantarray ) {
 	    my %comps;
 	    $comps{$_} = 1 foreach (map { keys %$_ } @$san);
-	    return keys %comps;
+	    return sort keys %comps;
 	}
 	my @string;
 	foreach my $comp (@$san) {
@@ -1103,7 +1103,7 @@ sub attributes {
     }
 
     unless( defined $name ) {
-	return grep { $_  ne 'extensionRequest' } keys %$attributes;
+	return grep { $_  ne 'extensionRequest' } sort keys %$attributes;
     }
 
     $name = $self->_oid2name( $name );
@@ -1113,6 +1113,10 @@ sub attributes {
 	return undef;
     }
 
+    # There can only be one matching the name.
+    # If the match becomes wider, sort the keys.
+
+
     my @attrs = grep { $_ eq $name } keys %$attributes;
     unless( @attrs ) {
 	return () if( wantarray );
@@ -1230,7 +1234,7 @@ sub extensionValue {
             $value = $entry->{extnValue};
 	    if( $apiVersion == 0 ) {
 		while (ref $value eq 'HASH') {
-		    my @keys = keys %{$value};
+		    my @keys = sort keys %{$value};
 		    $value = $value->{ shift @keys } ;
 		}
 	    } else {
@@ -1344,7 +1348,7 @@ Crypt::PKCS10 - parse PKCS #10 certificate requests
 
 =head1 VERSION
 
-version 1.403
+version 1.404
 
 =head1 SYNOPSIS
 
